window.Gleam.initSearch([{"doc":"gwr","title":"gwr","content":"# GWR - Gleam WebAssembly Runtime\n\n[![Package Version](https://img.shields.io/hexpm/v/gwr)](https://hex.pm/packages/gwr)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gwr/)\n[![Package License](https://img.shields.io/hexpm/l/gwr)](https://hex.pm/packages/gwr)\n[![Package Total Downloads Count](https://img.shields.io/hexpm/dt/gwr)](https://hex.pm/packages/gwr)\n[![Build Status](https://img.shields.io/github/actions/workflow/status/BrendoCosta/gwr/test.yml)](https://hex.pm/packages/gwr)\n[![Total Stars Count](https://img.shields.io/github/stars/BrendoCosta/gwr)](https://hex.pm/packages/gwr)\n\n## Description\n\nAn experimental work-in-progress (WIP) WebAssembly runtime written in Gleam.\n\n## Purpose\n\nNowadays, many languages ​​support Wasm as a target, from mainstream ones like C++ and Rust, as well as newer ones like Odin and Grain. The purpose of this project is to use WebAssembly to create an alternative interoperability layer to Erlang&#39;s virtual machine NIFs.\n\n## Installation\n\n```sh\ngleam add gwr\n```\n\n## Usage\n\n&gt; [!IMPORTANT]\n&gt; Currently the project is in an extremely early stage of development, it is only possible to run a simple sum function. Keep in mind that code and APIs may change dramatically.\n\n### Step 1 - Build code targeting Wasm\n\n#### Example - from Rust\n\n```rust\n// sum.rs\n\n#![no_std]\n\n#[panic_handler]\nfn panic(_info: &amp;core::panic::PanicInfo) -&gt; !\n{\n    loop {}\n}\n\n#[no_mangle]\npub extern fn sum(x: i32, y: i32) -&gt; i32\n{\n    x + y\n}\n```\n```sh\nrustc --crate-type cdylib --target wasm32-unknown-unknown -C debuginfo=none -C panic=abort -C strip=symbols -C opt-level=3 ./sum.rs -o ./sum.wasm\n```\n\n#### Example - from Wat\n\nUsing the wat2wasm tool from [wabt](https://github.com/WebAssembly/wabt).\n\n```wasm\n;; sum.wat\n\n(module\n    (type $t0 (func (param i32 i32) (result i32)))\n    (func $sum (export &quot;sum&quot;) (type $t0) (param $p0 i32) (param $p1 i32) (result i32)\n        (i32.add (local.get $p0) (local.get $p1))\n    )\n)\n```\n```sh\nwat2wasm -o ./sum.wasm ./sum.wat\n```\n\n### Step 2 - Run it from Gleam with GWR\n\nUsing the [simplifile](https://hex.pm/packages/simplifile) package to read the module file.\n\n```sh\ngleam add simplifile\n```\n\n```gleam\nimport gwr/execution/instance\nimport gwr/execution/runtime\nimport simplifile\n\npub fn main()\n{\n    let assert Ok(module_data) = simplifile.read_bits(from: &quot;sum.wasm&quot;)\n    let assert Ok(instance) = instance.create(from: module_data)\n    let assert Ok(#(instance, result)) = instance.call(instance, &quot;sum&quot;, [runtime.Number(4), runtime.Number(2)])\n    let assert [runtime.Number(6)] = result\n}\n```\n\n## Contributing\n\nContributions are welcome! Feel free to submit either issues or PRs, but keep in mind that your code needs to be covered by tests.\n\n## License\n\nGWR source code is avaliable under the [MIT license](/LICENSE).","url":"index.html"},{"doc":"gwr/syntax/convention","title":"Vector","content":"pub type Vector(a) =\n  List(a)\n https://webassembly.github.io/spec/core/syntax/conventions.html#vectors\n\nSynonyms:\ngwr/syntax/convention.Vector\ngwr/syntax/convention Vector","url":"gwr/syntax/convention.html#Vector"},{"doc":"gwr/syntax/convention","title":"gwr/syntax/convention","content":"","url":"gwr/syntax/convention.html"},{"doc":"gwr/syntax/index","title":"DataIndex","content":"pub type DataIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.DataIndex\ngwr/syntax/index DataIndex","url":"gwr/syntax/index.html#DataIndex"},{"doc":"gwr/syntax/index","title":"ElementIndex","content":"pub type ElementIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.ElementIndex\ngwr/syntax/index ElementIndex","url":"gwr/syntax/index.html#ElementIndex"},{"doc":"gwr/syntax/index","title":"FunctionIndex","content":"pub type FunctionIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.FunctionIndex\ngwr/syntax/index FunctionIndex","url":"gwr/syntax/index.html#FunctionIndex"},{"doc":"gwr/syntax/index","title":"GlobalIndex","content":"pub type GlobalIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.GlobalIndex\ngwr/syntax/index GlobalIndex","url":"gwr/syntax/index.html#GlobalIndex"},{"doc":"gwr/syntax/index","title":"LabelIndex","content":"pub type LabelIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.LabelIndex\ngwr/syntax/index LabelIndex","url":"gwr/syntax/index.html#LabelIndex"},{"doc":"gwr/syntax/index","title":"LocalIndex","content":"pub type LocalIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.LocalIndex\ngwr/syntax/index LocalIndex","url":"gwr/syntax/index.html#LocalIndex"},{"doc":"gwr/syntax/index","title":"MemoryIndex","content":"pub type MemoryIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.MemoryIndex\ngwr/syntax/index MemoryIndex","url":"gwr/syntax/index.html#MemoryIndex"},{"doc":"gwr/syntax/index","title":"TableIndex","content":"pub type TableIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.TableIndex\ngwr/syntax/index TableIndex","url":"gwr/syntax/index.html#TableIndex"},{"doc":"gwr/syntax/index","title":"TypeIndex","content":"pub type TypeIndex =\n  Int\n\n\nSynonyms:\ngwr/syntax/index.TypeIndex\ngwr/syntax/index TypeIndex","url":"gwr/syntax/index.html#TypeIndex"},{"doc":"gwr/syntax/index","title":"gwr/syntax/index","content":"","url":"gwr/syntax/index.html"},{"doc":"gwr/syntax/instruction","title":"Expression","content":"pub type Expression =\n  List(Instruction)\n Function bodies, initialization values for globals, elements and offsets\n of element segments, and offsets of data segments are given as expressions,\n which are sequences of instructions terminated by an &lt;end&gt; marker.\n \n https://webassembly.github.io/spec/core/syntax/instructions.html#expressions\n\nSynonyms:\ngwr/syntax/instruction.Expression\ngwr/syntax/instruction Expression","url":"gwr/syntax/instruction.html#Expression"},{"doc":"gwr/syntax/instruction","title":"Instruction","content":"pub type Instruction {\n  Unreachable\n  NoOp\n  LocalGet(index: index.LocalIndex)\n  I32Add\n  I32Const(value: Int)\n  End\n}\n\nUnreachable\n https://webassembly.github.io/spec/core/binary/instructions.html#control-instructions\n\nNoOp\n\n\nLocalGet(index: index.LocalIndex)\n https://webassembly.github.io/spec/core/binary/instructions.html#variable-instructions\n\nI32Add\n https://webassembly.github.io/spec/core/binary/instructions.html#numeric-instructions\n\nI32Const(value: Int)\n\n\nEnd\n https://webassembly.github.io/spec/core/binary/instructions.html#expressions\n\nSynonyms:\ngwr/syntax/instruction.Instruction\ngwr/syntax/instruction Instruction","url":"gwr/syntax/instruction.html#Instruction"},{"doc":"gwr/syntax/instruction","title":"gwr/syntax/instruction","content":"","url":"gwr/syntax/instruction.html"},{"doc":"gwr/syntax/types","title":"ExternalType","content":"pub type ExternalType {\n  Function(FunctionType)\n  Table(TableType)\n  Memory(MemoryType)\n  Global(GlobalType)\n}\n External types classify imports and external values with their respective types.\n \n https://webassembly.github.io/spec/core/syntax/types.html#external-types\nFunction(FunctionType)\n\n\nTable(TableType)\n\n\nMemory(MemoryType)\n\n\nGlobal(GlobalType)\n\n\nSynonyms:\ngwr/syntax/types.ExternalType\ngwr/syntax/types ExternalType","url":"gwr/syntax/types.html#ExternalType"},{"doc":"gwr/syntax/types","title":"FunctionType","content":"pub type FunctionType {\n  FunctionType(\n    parameters: List(ValueType),\n    results: List(ValueType),\n  )\n}\n Function types classify the signature of functions, mapping a vector of parameters\n to a vector of results. They are also used to classify the inputs and outputs of instructions.\n \n https://webassembly.github.io/spec/core/syntax/types.html#function-types\nFunctionType(\n  parameters: List(ValueType),\n  results: List(ValueType),\n)\n\n\nSynonyms:\ngwr/syntax/types.FunctionType\ngwr/syntax/types FunctionType","url":"gwr/syntax/types.html#FunctionType"},{"doc":"gwr/syntax/types","title":"GlobalType","content":"pub type GlobalType {\n  GlobalType(mutability: Mutability, value_type: ValueType)\n}\n Global types classify global variables, which hold a value and can either be mutable or immutable.\n \n https://webassembly.github.io/spec/core/syntax/types.html#global-types\nGlobalType(mutability: Mutability, value_type: ValueType)\n\n\nSynonyms:\ngwr/syntax/types.GlobalType\ngwr/syntax/types GlobalType","url":"gwr/syntax/types.html#GlobalType"},{"doc":"gwr/syntax/types","title":"Limits","content":"pub type Limits {\n  Limits(min: Int, max: Option(Int))\n}\n Limits classify the size range of resizeable storage associated with memory types and table types.\n \n https://webassembly.github.io/spec/core/syntax/types.html#limits\nLimits(min: Int, max: Option(Int))\n\n\nSynonyms:\ngwr/syntax/types.Limits\ngwr/syntax/types Limits","url":"gwr/syntax/types.html#Limits"},{"doc":"gwr/syntax/types","title":"MemoryType","content":"pub type MemoryType =\n  Limits\n Memory types classify linear memories and their size range.\n \n https://webassembly.github.io/spec/core/syntax/types.html#memory-types\n\nSynonyms:\ngwr/syntax/types.MemoryType\ngwr/syntax/types MemoryType","url":"gwr/syntax/types.html#MemoryType"},{"doc":"gwr/syntax/types","title":"Mutability","content":"pub type Mutability {\n  Constant\n  Variable\n}\n\nConstant\n\n\nVariable\n\n\nSynonyms:\ngwr/syntax/types.Mutability\ngwr/syntax/types Mutability","url":"gwr/syntax/types.html#Mutability"},{"doc":"gwr/syntax/types","title":"NumberType","content":"pub type NumberType {\n  Integer32\n  Integer64\n  Float32\n  Float64\n}\n Number types classify numeric values.\n \n https://webassembly.github.io/spec/core/syntax/types.html#number-types\nInteger32\n\n\nInteger64\n\n\nFloat32\n\n\nFloat64\n\n\nSynonyms:\ngwr/syntax/types.NumberType\ngwr/syntax/types NumberType","url":"gwr/syntax/types.html#NumberType"},{"doc":"gwr/syntax/types","title":"ReferenceType","content":"pub type ReferenceType {\n  FunctionReference\n  ExternReference\n}\n Reference types classify first-class references to objects in the runtime store.\n \n https://webassembly.github.io/spec/core/syntax/types.html#reference-types\nFunctionReference\n\n\nExternReference\n\n\nSynonyms:\ngwr/syntax/types.ReferenceType\ngwr/syntax/types ReferenceType","url":"gwr/syntax/types.html#ReferenceType"},{"doc":"gwr/syntax/types","title":"ResultType","content":"pub type ResultType =\n  List(ValueType)\n Result types classify the result of executing instructions or functions,\n which is a sequence of values, written with brackets.\n \n https://webassembly.github.io/spec/core/syntax/types.html#result-types\n\nSynonyms:\ngwr/syntax/types.ResultType\ngwr/syntax/types ResultType","url":"gwr/syntax/types.html#ResultType"},{"doc":"gwr/syntax/types","title":"TableType","content":"pub type TableType {\n  TableType(limits: Limits, elements: ReferenceType)\n}\n Table types classify tables over elements of reference type within a size range.\n \n https://webassembly.github.io/spec/core/syntax/types.html#syntax-tabletype\nTableType(limits: Limits, elements: ReferenceType)\n\n\nSynonyms:\ngwr/syntax/types.TableType\ngwr/syntax/types TableType","url":"gwr/syntax/types.html#TableType"},{"doc":"gwr/syntax/types","title":"ValueType","content":"pub type ValueType {\n  Number(NumberType)\n  Vector(VectorType)\n  Reference(ReferenceType)\n}\n Value types classify the individual values that WebAssembly code can compute\n with and the values that a variable accepts. They are either number types,\n vector types, or reference types.\n \n https://webassembly.github.io/spec/core/syntax/types.html#value-types\nNumber(NumberType)\n\n\nVector(VectorType)\n\n\nReference(ReferenceType)\n\n\nSynonyms:\ngwr/syntax/types.ValueType\ngwr/syntax/types ValueType","url":"gwr/syntax/types.html#ValueType"},{"doc":"gwr/syntax/types","title":"VectorType","content":"pub type VectorType {\n  Vector128\n}\n Vector types classify vectors of numeric values processed by vector instructions (also known as SIMD instructions, single instruction multiple data).\n \n https://webassembly.github.io/spec/core/syntax/types.html#vector-types\nVector128\n\n\nSynonyms:\ngwr/syntax/types.VectorType\ngwr/syntax/types VectorType","url":"gwr/syntax/types.html#VectorType"},{"doc":"gwr/syntax/types","title":"gwr/syntax/types","content":"","url":"gwr/syntax/types.html"},{"doc":"gwr/syntax/value","title":"Name","content":"pub type Name =\n  String\n Names are sequences of characters, which are scalar values as defined by Unicode (Section 2.4).\n \n https://webassembly.github.io/spec/core/syntax/values.html#names\n\nSynonyms:\ngwr/syntax/value.Name\ngwr/syntax/value Name","url":"gwr/syntax/value.html#Name"},{"doc":"gwr/syntax/value","title":"gwr/syntax/value","content":"","url":"gwr/syntax/value.html"},{"doc":"gwr/syntax/module","title":"DataSegment","content":"pub type DataSegment {\n  DataSegment(init: BitArray, mode: DataSegmentMode)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#data-segments\nDataSegment(init: BitArray, mode: DataSegmentMode)\n\n\nSynonyms:\ngwr/syntax/module.DataSegment\ngwr/syntax/module DataSegment","url":"gwr/syntax/module.html#DataSegment"},{"doc":"gwr/syntax/module","title":"DataSegmentMode","content":"pub type DataSegmentMode {\n  PassiveDataSegment\n  ActiveDataSegment(\n    memory: index.MemoryIndex,\n    offset: instruction.Expression,\n  )\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#data-segments\nPassiveDataSegment\n\n\nActiveDataSegment(\n  memory: index.MemoryIndex,\n  offset: instruction.Expression,\n)\n\n\nSynonyms:\ngwr/syntax/module.DataSegmentMode\ngwr/syntax/module DataSegmentMode","url":"gwr/syntax/module.html#DataSegmentMode"},{"doc":"gwr/syntax/module","title":"ElementSegment","content":"pub type ElementSegment {\n  ElementSegment(\n    type_: types.ReferenceType,\n    init: convention.Vector(instruction.Expression),\n    mode: ElementSegmentMode,\n  )\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#element-segments\nElementSegment(\n  type_: types.ReferenceType,\n  init: convention.Vector(instruction.Expression),\n  mode: ElementSegmentMode,\n)\n\n\nSynonyms:\ngwr/syntax/module.ElementSegment\ngwr/syntax/module ElementSegment","url":"gwr/syntax/module.html#ElementSegment"},{"doc":"gwr/syntax/module","title":"ElementSegmentMode","content":"pub type ElementSegmentMode {\n  PassiveElementSegment\n  ActiveElementSegment(\n    table: index.TableIndex,\n    offset: instruction.Expression,\n  )\n  DeclarativeElementSegment\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#element-segments\nPassiveElementSegment\n\n\nActiveElementSegment(\n  table: index.TableIndex,\n  offset: instruction.Expression,\n)\n\n\nDeclarativeElementSegment\n\n\nSynonyms:\ngwr/syntax/module.ElementSegmentMode\ngwr/syntax/module ElementSegmentMode","url":"gwr/syntax/module.html#ElementSegmentMode"},{"doc":"gwr/syntax/module","title":"Export","content":"pub type Export {\n  Export(name: value.Name, descriptor: ExportDescriptor)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#exports\nExport(name: value.Name, descriptor: ExportDescriptor)\n\n\nSynonyms:\ngwr/syntax/module.Export\ngwr/syntax/module Export","url":"gwr/syntax/module.html#Export"},{"doc":"gwr/syntax/module","title":"ExportDescriptor","content":"pub type ExportDescriptor {\n  FunctionExport(index: index.FunctionIndex)\n  TableExport(index: index.TableIndex)\n  MemoryExport(index: index.MemoryIndex)\n  GlobalExport(index: index.GlobalIndex)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#exports\nFunctionExport(index: index.FunctionIndex)\n\n\nTableExport(index: index.TableIndex)\n\n\nMemoryExport(index: index.MemoryIndex)\n\n\nGlobalExport(index: index.GlobalIndex)\n\n\nSynonyms:\ngwr/syntax/module.ExportDescriptor\ngwr/syntax/module ExportDescriptor","url":"gwr/syntax/module.html#ExportDescriptor"},{"doc":"gwr/syntax/module","title":"Function","content":"pub type Function {\n  Function(\n    type_: index.TypeIndex,\n    locals: convention.Vector(types.ValueType),\n    body: instruction.Expression,\n  )\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#functions\nFunction(\n  type_: index.TypeIndex,\n  locals: convention.Vector(types.ValueType),\n  body: instruction.Expression,\n)\n\n\nSynonyms:\ngwr/syntax/module.Function\ngwr/syntax/module Function","url":"gwr/syntax/module.html#Function"},{"doc":"gwr/syntax/module","title":"Global","content":"pub type Global {\n  Global(type_: types.GlobalType, init: instruction.Expression)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#globals\nGlobal(type_: types.GlobalType, init: instruction.Expression)\n\n\nSynonyms:\ngwr/syntax/module.Global\ngwr/syntax/module Global","url":"gwr/syntax/module.html#Global"},{"doc":"gwr/syntax/module","title":"Import","content":"pub type Import {\n  Import(\n    module: value.Name,\n    name: value.Name,\n    descriptor: ImportDescriptor,\n  )\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#imports\nImport(\n  module: value.Name,\n  name: value.Name,\n  descriptor: ImportDescriptor,\n)\n\n\nSynonyms:\ngwr/syntax/module.Import\ngwr/syntax/module Import","url":"gwr/syntax/module.html#Import"},{"doc":"gwr/syntax/module","title":"ImportDescriptor","content":"pub type ImportDescriptor {\n  FunctionImport(function: index.FunctionIndex)\n  TableImport(table: types.TableType)\n  MemoryImport(memory: types.MemoryType)\n  GlobalImport(global: types.GlobalType)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#imports\nFunctionImport(function: index.FunctionIndex)\n\n\nTableImport(table: types.TableType)\n\n\nMemoryImport(memory: types.MemoryType)\n\n\nGlobalImport(global: types.GlobalType)\n\n\nSynonyms:\ngwr/syntax/module.ImportDescriptor\ngwr/syntax/module ImportDescriptor","url":"gwr/syntax/module.html#ImportDescriptor"},{"doc":"gwr/syntax/module","title":"Memory","content":"pub type Memory {\n  Memory(type_: types.MemoryType)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#memories\nMemory(type_: types.MemoryType)\n\n\nSynonyms:\ngwr/syntax/module.Memory\ngwr/syntax/module Memory","url":"gwr/syntax/module.html#Memory"},{"doc":"gwr/syntax/module","title":"Module","content":"pub type Module {\n  Module(\n    types: convention.Vector(types.FunctionType),\n    functions: convention.Vector(Function),\n    tables: convention.Vector(Table),\n    memories: convention.Vector(Memory),\n    globals: convention.Vector(Global),\n    elements: convention.Vector(ElementSegment),\n    datas: convention.Vector(DataSegment),\n    start: Option(StartFunction),\n    imports: convention.Vector(Import),\n    exports: convention.Vector(Export),\n  )\n}\n WebAssembly programs are organized into modules, which are the unit of deployment,\n loading, and compilation. A module collects definitions for types, functions, tables,\n memories, and globals. In addition, it can declare imports and exports and provide\n initialization in the form of data and element segments, or a start function.\n \n https://webassembly.github.io/spec/core/syntax/modules.html#modules\nModule(\n  types: convention.Vector(types.FunctionType),\n  functions: convention.Vector(Function),\n  tables: convention.Vector(Table),\n  memories: convention.Vector(Memory),\n  globals: convention.Vector(Global),\n  elements: convention.Vector(ElementSegment),\n  datas: convention.Vector(DataSegment),\n  start: Option(StartFunction),\n  imports: convention.Vector(Import),\n  exports: convention.Vector(Export),\n)\n\n\nSynonyms:\ngwr/syntax/module.Module\ngwr/syntax/module Module","url":"gwr/syntax/module.html#Module"},{"doc":"gwr/syntax/module","title":"StartFunction","content":"pub type StartFunction {\n  StartFunction(function: index.FunctionIndex)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#start-function\nStartFunction(function: index.FunctionIndex)\n\n\nSynonyms:\ngwr/syntax/module.StartFunction\ngwr/syntax/module StartFunction","url":"gwr/syntax/module.html#StartFunction"},{"doc":"gwr/syntax/module","title":"Table","content":"pub type Table {\n  Table(type_: types.TableType)\n}\n https://webassembly.github.io/spec/core/syntax/modules.html#tables\nTable(type_: types.TableType)\n\n\nSynonyms:\ngwr/syntax/module.Table\ngwr/syntax/module Table","url":"gwr/syntax/module.html#Table"},{"doc":"gwr/syntax/module","title":"gwr/syntax/module","content":"","url":"gwr/syntax/module.html"},{"doc":"gwr/binary","title":"Binary","content":"pub type Binary {\n  Binary(version: Int, length: Int, module: module.Module)\n}\n\nBinary(version: Int, length: Int, module: module.Module)\n\n\nSynonyms:\ngwr/binary.Binary\ngwr/binary Binary","url":"gwr/binary.html#Binary"},{"doc":"gwr/binary","title":"Code","content":"pub type Code {\n  Code(size: Int, function_code: FunctionCode)\n}\n\nCode(size: Int, function_code: FunctionCode)\n\n\nSynonyms:\ngwr/binary.Code\ngwr/binary Code","url":"gwr/binary.html#Code"},{"doc":"gwr/binary","title":"FunctionCode","content":"pub type FunctionCode {\n  FunctionCode(\n    locals: convention.Vector(LocalsDeclaration),\n    body: instruction.Expression,\n  )\n}\n\nFunctionCode(\n  locals: convention.Vector(LocalsDeclaration),\n  body: instruction.Expression,\n)\n\n\nSynonyms:\ngwr/binary.FunctionCode\ngwr/binary FunctionCode","url":"gwr/binary.html#FunctionCode"},{"doc":"gwr/binary","title":"LocalsDeclaration","content":"pub type LocalsDeclaration {\n  LocalsDeclaration(count: Int, type_: types.ValueType)\n}\n\nLocalsDeclaration(count: Int, type_: types.ValueType)\n\n\nSynonyms:\ngwr/binary.LocalsDeclaration\ngwr/binary LocalsDeclaration","url":"gwr/binary.html#LocalsDeclaration"},{"doc":"gwr/binary","title":"Section","content":"pub type Section {\n  Section(id: Int, length: Int, content: Option(SectionContent))\n}\n Each section consists of\n     - a one-byte section id,\n     - the u32 size of the contents, in bytes,\n     - the actual contents, whose structure is dependent on the section id.\n https://webassembly.github.io/spec/core/binary/module.html#sections\nSection(id: Int, length: Int, content: Option(SectionContent))\n\n\nSynonyms:\ngwr/binary.Section\ngwr/binary Section","url":"gwr/binary.html#Section"},{"doc":"gwr/binary","title":"SectionContent","content":"pub type SectionContent {\n  CustomSection(name: String, data: Option(BitArray))\n  TypeSection(\n    function_types: convention.Vector(types.FunctionType),\n  )\n  ImportSection\n  FunctionSection(type_indices: convention.Vector(Int))\n  TableSection\n  MemorySection(memories: convention.Vector(module.Memory))\n  GlobalSection(globals: convention.Vector(module.Global))\n  ExportSection(exports: convention.Vector(module.Export))\n  StartSection(start_function: module.StartFunction)\n  ElementSection\n  CodeSection(entries: List(Code))\n  DataSection\n  DataCountSection\n}\n\nCustomSection(name: String, data: Option(BitArray))\n Custom sections have the id 0. They are intended to be used for debugging information\n or third-party extensions, and are ignored by the WebAssembly semantics. Their contents\n consist of a name further identifying the custom section, followed by an uninterpreted\n sequence of bytes for custom use.\n \n https://webassembly.github.io/spec/core/binary/module.html#custom-section\n\nTypeSection(\n  function_types: convention.Vector(types.FunctionType),\n)\n The type section has the id 1. It decodes into a vector of function types that represent\n the component of a module.\n \n https://webassembly.github.io/spec/core/binary/module.html#type-section\n\nImportSection\n\n\nFunctionSection(type_indices: convention.Vector(Int))\n The function section has the id 3. It decodes into a vector of type indices that represent\n the &lt;type&gt; fields of the functions in the &lt;funcs&gt; component of a module. The &lt;locals&gt; and\n &lt;body&gt; fields of the respective functions are encoded separately in the code section.\n \n https://webassembly.github.io/spec/core/binary/module.html#function-section\n\nTableSection\n The table section has the id 4. It decodes into a vector of tables that represent the &lt;table&gt;\n component of a module.\n \n https://webassembly.github.io/spec/core/binary/modules.html#table-section\n\nMemorySection(memories: convention.Vector(module.Memory))\n The memory section has the id 5. It decodes into a vector of memories that represent the &lt;mems&gt;\n component of a module.\n \n https://webassembly.github.io/spec/core/binary/modules.html#memory-section\n\nGlobalSection(globals: convention.Vector(module.Global))\n The global section has the id 6. It decodes into a vector of globals that represent the &lt;globals&gt;\n component of a module.\n \n https://webassembly.github.io/spec/core/binary/modules.html#global-section\n\nExportSection(exports: convention.Vector(module.Export))\n The export section has the id 7. It decodes into a vector of exports that represent the exports\n component of a module.\n \n https://webassembly.github.io/spec/core/binary/module.html#export-section\n\nStartSection(start_function: module.StartFunction)\n The start section has the id 8. It decodes into an optional start function that represents the\n &lt;start&gt; component of a module.\n \n https://webassembly.github.io/spec/core/binary/modules.html#start-section\n\nElementSection\n\n\nCodeSection(entries: List(Code))\n\n\nDataSection\n\n\nDataCountSection\n\n\nSynonyms:\ngwr/binary.SectionContent\ngwr/binary SectionContent","url":"gwr/binary.html#SectionContent"},{"doc":"gwr/binary","title":"code_section_id","content":"pub const code_section_id: Int\n\nSynonyms:\ngwr/binary.code_section_id\ngwr/binary code_section_id","url":"gwr/binary.html#code_section_id"},{"doc":"gwr/binary","title":"custom_section_id","content":"pub const custom_section_id: Int\n https://webassembly.github.io/spec/core/binary/module.html#sections\nSynonyms:\ngwr/binary.custom_section_id\ngwr/binary custom_section_id","url":"gwr/binary.html#custom_section_id"},{"doc":"gwr/binary","title":"data_count_section_id","content":"pub const data_count_section_id: Int\n\nSynonyms:\ngwr/binary.data_count_section_id\ngwr/binary data_count_section_id","url":"gwr/binary.html#data_count_section_id"},{"doc":"gwr/binary","title":"data_section_id","content":"pub const data_section_id: Int\n\nSynonyms:\ngwr/binary.data_section_id\ngwr/binary data_section_id","url":"gwr/binary.html#data_section_id"},{"doc":"gwr/binary","title":"element_section_id","content":"pub const element_section_id: Int\n\nSynonyms:\ngwr/binary.element_section_id\ngwr/binary element_section_id","url":"gwr/binary.html#element_section_id"},{"doc":"gwr/binary","title":"export_section_id","content":"pub const export_section_id: Int\n\nSynonyms:\ngwr/binary.export_section_id\ngwr/binary export_section_id","url":"gwr/binary.html#export_section_id"},{"doc":"gwr/binary","title":"function_section_id","content":"pub const function_section_id: Int\n\nSynonyms:\ngwr/binary.function_section_id\ngwr/binary function_section_id","url":"gwr/binary.html#function_section_id"},{"doc":"gwr/binary","title":"global_section_id","content":"pub const global_section_id: Int\n\nSynonyms:\ngwr/binary.global_section_id\ngwr/binary global_section_id","url":"gwr/binary.html#global_section_id"},{"doc":"gwr/binary","title":"import_section_id","content":"pub const import_section_id: Int\n\nSynonyms:\ngwr/binary.import_section_id\ngwr/binary import_section_id","url":"gwr/binary.html#import_section_id"},{"doc":"gwr/binary","title":"memory_section_id","content":"pub const memory_section_id: Int\n\nSynonyms:\ngwr/binary.memory_section_id\ngwr/binary memory_section_id","url":"gwr/binary.html#memory_section_id"},{"doc":"gwr/binary","title":"start_section_id","content":"pub const start_section_id: Int\n\nSynonyms:\ngwr/binary.start_section_id\ngwr/binary start_section_id","url":"gwr/binary.html#start_section_id"},{"doc":"gwr/binary","title":"table_section_id","content":"pub const table_section_id: Int\n\nSynonyms:\ngwr/binary.table_section_id\ngwr/binary table_section_id","url":"gwr/binary.html#table_section_id"},{"doc":"gwr/binary","title":"type_section_id","content":"pub const type_section_id: Int\n\nSynonyms:\ngwr/binary.type_section_id\ngwr/binary type_section_id","url":"gwr/binary.html#type_section_id"},{"doc":"gwr/binary","title":"gwr/binary","content":"","url":"gwr/binary.html"},{"doc":"gwr/execution/runtime","title":"Address","content":"pub type Address {\n  FunctionAddress(Int)\n  TableAddress(Int)\n  MemoryAddress(Int)\n  GlobalAddress(Int)\n  ElementAddress(Int)\n  DataAddress(Int)\n  ExternAddress(Int)\n}\n https://webassembly.github.io/spec/core/exec/runtime.html#addresses\nFunctionAddress(Int)\n\n\nTableAddress(Int)\n\n\nMemoryAddress(Int)\n\n\nGlobalAddress(Int)\n\n\nElementAddress(Int)\n\n\nDataAddress(Int)\n\n\nExternAddress(Int)\n\n\nSynonyms:\ngwr/execution/runtime.Address\ngwr/execution/runtime Address","url":"gwr/execution/runtime.html#Address"},{"doc":"gwr/execution/runtime","title":"DataInstance","content":"pub type DataInstance {\n  DataInstance(data: BitArray)\n}\n An data instance is the runtime representation of a data segment. It holds a vector of bytes.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#data-instances\nDataInstance(data: BitArray)\n\n\nSynonyms:\ngwr/execution/runtime.DataInstance\ngwr/execution/runtime DataInstance","url":"gwr/execution/runtime.html#DataInstance"},{"doc":"gwr/execution/runtime","title":"ElementInstance","content":"pub type ElementInstance {\n  ElementInstance(\n    type_: types.ReferenceType,\n    element: List(Value),\n  )\n}\n An element instance is the runtime representation of an element segment. It holds a\n vector of references and their common type.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#element-instances\nElementInstance(type_: types.ReferenceType, element: List(Value))\n\n\nSynonyms:\ngwr/execution/runtime.ElementInstance\ngwr/execution/runtime ElementInstance","url":"gwr/execution/runtime.html#ElementInstance"},{"doc":"gwr/execution/runtime","title":"ExecutionResult","content":"pub type ExecutionResult {\n  Success(List(Value))\n  Trap\n}\n A result is the outcome of a computation. It is either a sequence of values or a trap.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#results\nSuccess(List(Value))\n\n\nTrap\n\n\nSynonyms:\ngwr/execution/runtime.ExecutionResult\ngwr/execution/runtime ExecutionResult","url":"gwr/execution/runtime.html#ExecutionResult"},{"doc":"gwr/execution/runtime","title":"ExportInstance","content":"pub type ExportInstance {\n  ExportInstance(name: value.Name, value: ExternalValue)\n}\n An export instance is the runtime representation of an export. It defines\n the export’s name and the associated external value.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#export-instances\nExportInstance(name: value.Name, value: ExternalValue)\n\n\nSynonyms:\ngwr/execution/runtime.ExportInstance\ngwr/execution/runtime ExportInstance","url":"gwr/execution/runtime.html#ExportInstance"},{"doc":"gwr/execution/runtime","title":"ExternalValue","content":"pub type ExternalValue {\n  Function(Address)\n  Table(Address)\n  Memory(Address)\n  Global(Address)\n}\n An external value is the runtime representation of an entity that can be imported\n or exported. It is an address denoting either a function instance, table instance,\n memory instance, or global instances in the shared store.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#external-values\nFunction(Address)\n\n\nTable(Address)\n\n\nMemory(Address)\n\n\nGlobal(Address)\n\n\nSynonyms:\ngwr/execution/runtime.ExternalValue\ngwr/execution/runtime ExternalValue","url":"gwr/execution/runtime.html#ExternalValue"},{"doc":"gwr/execution/runtime","title":"FunctionInstance","content":"pub type FunctionInstance {\n  WebAssemblyFunctionInstance(\n    type_: types.FunctionType,\n    module_instance: ModuleInstance,\n    code: module.Function,\n  )\n  HostFunctionInstance(\n    type_: types.FunctionType,\n    code: fn(List(dynamic.Dynamic)) -&gt; List(dynamic.Dynamic),\n  )\n}\n A function instance is the runtime representation of a function. It effectively is a\n closure of the original function over the runtime module instance of its originating\n module. The module instance is used to resolve references to other definitions during\n execution of the function.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#function-instances\nWebAssemblyFunctionInstance(\n  type_: types.FunctionType,\n  module_instance: ModuleInstance,\n  code: module.Function,\n)\n\n\nHostFunctionInstance(\n  type_: types.FunctionType,\n  code: fn(List(dynamic.Dynamic)) -&gt; List(dynamic.Dynamic),\n)\n\n\nSynonyms:\ngwr/execution/runtime.FunctionInstance\ngwr/execution/runtime FunctionInstance","url":"gwr/execution/runtime.html#FunctionInstance"},{"doc":"gwr/execution/runtime","title":"GlobalInstance","content":"pub type GlobalInstance {\n  GlobalInstance(type_: types.GlobalType, value: Value)\n}\n A global instance is the runtime representation of a global variable. It records its\n type and holds an individual value.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#global-instances\nGlobalInstance(type_: types.GlobalType, value: Value)\n\n\nSynonyms:\ngwr/execution/runtime.GlobalInstance\ngwr/execution/runtime GlobalInstance","url":"gwr/execution/runtime.html#GlobalInstance"},{"doc":"gwr/execution/runtime","title":"MemoryInstance","content":"pub type MemoryInstance {\n  MemoryInstance(type_: types.MemoryType, data: BitArray)\n}\n A memory instance is the runtime representation of a linear memory. It records its\n type and holds a vector of bytes.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#memory-instances\nMemoryInstance(type_: types.MemoryType, data: BitArray)\n\n\nSynonyms:\ngwr/execution/runtime.MemoryInstance\ngwr/execution/runtime MemoryInstance","url":"gwr/execution/runtime.html#MemoryInstance"},{"doc":"gwr/execution/runtime","title":"ModuleInstance","content":"pub type ModuleInstance {\n  ModuleInstance(\n    types: List(types.FunctionType),\n    function_addresses: List(Address),\n    table_addresses: List(Address),\n    memory_addresses: List(Address),\n    global_addresses: List(Address),\n    element_addresses: List(Address),\n    data_addresses: List(Address),\n    exports: List(ExportInstance),\n  )\n}\n A module instance is the runtime representation of a module. It is created by instantiating\n a module, and collects runtime representations of all entities that are imported, defined,\n or exported by the module.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#module-instances\nModuleInstance(\n  types: List(types.FunctionType),\n  function_addresses: List(Address),\n  table_addresses: List(Address),\n  memory_addresses: List(Address),\n  global_addresses: List(Address),\n  element_addresses: List(Address),\n  data_addresses: List(Address),\n  exports: List(ExportInstance),\n)\n\n\nSynonyms:\ngwr/execution/runtime.ModuleInstance\ngwr/execution/runtime ModuleInstance","url":"gwr/execution/runtime.html#ModuleInstance"},{"doc":"gwr/execution/runtime","title":"ReferenceValueType","content":"pub type ReferenceValueType {\n  Null\n  ToFunctionAddress(Address)\n  ToExternAddress(Address)\n}\n\nNull\n\n\nToFunctionAddress(Address)\n\n\nToExternAddress(Address)\n\n\nSynonyms:\ngwr/execution/runtime.ReferenceValueType\ngwr/execution/runtime ReferenceValueType","url":"gwr/execution/runtime.html#ReferenceValueType"},{"doc":"gwr/execution/runtime","title":"Store","content":"pub type Store {\n  Store(\n    functions: List(FunctionInstance),\n    tables: List(TableInstance),\n    memories: List(MemoryInstance),\n    globals: List(GlobalInstance),\n    elements: List(ElementInstance),\n    datas: List(DataInstance),\n  )\n}\n The store represents all global state that can be manipulated by WebAssembly programs.\n It consists of the runtime representation of all instances of functions, tables, memories,\n and globals, element segments, and data segments that have been allocated during the\n life time of the abstract machine.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#store\nStore(\n  functions: List(FunctionInstance),\n  tables: List(TableInstance),\n  memories: List(MemoryInstance),\n  globals: List(GlobalInstance),\n  elements: List(ElementInstance),\n  datas: List(DataInstance),\n)\n\n\nSynonyms:\ngwr/execution/runtime.Store\ngwr/execution/runtime Store","url":"gwr/execution/runtime.html#Store"},{"doc":"gwr/execution/runtime","title":"TableInstance","content":"pub type TableInstance {\n  TableInstance(type_: types.TableType, elements: List(Value))\n}\n A table instance is the runtime representation of a table. It records its type and\n holds a vector of reference value.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#table-instances\nTableInstance(type_: types.TableType, elements: List(Value))\n\n\nSynonyms:\ngwr/execution/runtime.TableInstance\ngwr/execution/runtime TableInstance","url":"gwr/execution/runtime.html#TableInstance"},{"doc":"gwr/execution/runtime","title":"Value","content":"pub type Value {\n  Number(Int)\n  Vector(Int)\n  Reference(ReferenceValueType)\n}\n https://webassembly.github.io/spec/core/exec/runtime.html#values\nNumber(Int)\n\n\nVector(Int)\n\n\nReference(ReferenceValueType)\n\n\nSynonyms:\ngwr/execution/runtime.Value\ngwr/execution/runtime Value","url":"gwr/execution/runtime.html#Value"},{"doc":"gwr/execution/runtime","title":"number_value_default_value","content":"pub const number_value_default_value: Int\n\nSynonyms:\ngwr/execution/runtime.number_value_default_value\ngwr/execution/runtime number_value_default_value","url":"gwr/execution/runtime.html#number_value_default_value"},{"doc":"gwr/execution/runtime","title":"reference_value_default_value","content":"pub const reference_value_default_value: ReferenceValueType\n\nSynonyms:\ngwr/execution/runtime.reference_value_default_value\ngwr/execution/runtime reference_value_default_value","url":"gwr/execution/runtime.html#reference_value_default_value"},{"doc":"gwr/execution/runtime","title":"vector_value_default_value","content":"pub const vector_value_default_value: Int\n\nSynonyms:\ngwr/execution/runtime.vector_value_default_value\ngwr/execution/runtime vector_value_default_value","url":"gwr/execution/runtime.html#vector_value_default_value"},{"doc":"gwr/execution/runtime","title":"gwr/execution/runtime","content":"","url":"gwr/execution/runtime.html"},{"doc":"gwr/execution/stack","title":"ActivationFrame","content":"pub type ActivationFrame {\n  ActivationFrame(arity: Int, framestate: FrameState)\n}\n Activation frames carry the return arity &lt;n&gt; of the respective function, hold the values of\n its locals (including arguments) in the order corresponding to their static local indices, and\n a reference to the function’s own module instance:\n \n https://webassembly.github.io/spec/core/exec/runtime.html#activation-frames\nActivationFrame(arity: Int, framestate: FrameState)\n\n\nSynonyms:\ngwr/execution/stack.ActivationFrame\ngwr/execution/stack ActivationFrame","url":"gwr/execution/stack.html#ActivationFrame"},{"doc":"gwr/execution/stack","title":"FrameState","content":"pub type FrameState {\n  FrameState(\n    locals: List(runtime.Value),\n    module_instance: runtime.ModuleInstance,\n  )\n}\n https://webassembly.github.io/spec/core/exec/runtime.html#activation-frames\nFrameState(\n  locals: List(runtime.Value),\n  module_instance: runtime.ModuleInstance,\n)\n\n\nSynonyms:\ngwr/execution/stack.FrameState\ngwr/execution/stack FrameState","url":"gwr/execution/stack.html#FrameState"},{"doc":"gwr/execution/stack","title":"Label","content":"pub type Label {\n  Label(arity: Int, target: List(instruction.Instruction))\n}\n Labels carry an argument arity &lt;n&gt; and their associated branch target, which is expressed\n syntactically as an instruction sequence:\n \n https://webassembly.github.io/spec/core/exec/runtime.html#labels\nLabel(arity: Int, target: List(instruction.Instruction))\n\n\nSynonyms:\ngwr/execution/stack.Label\ngwr/execution/stack Label","url":"gwr/execution/stack.html#Label"},{"doc":"gwr/execution/stack","title":"Stack","content":"pub type Stack {\n  Stack(entries: List(StackEntry))\n}\n https://webassembly.github.io/spec/core/exec/runtime.html#stack\nStack(entries: List(StackEntry))\n\n\nSynonyms:\ngwr/execution/stack.Stack\ngwr/execution/stack Stack","url":"gwr/execution/stack.html#Stack"},{"doc":"gwr/execution/stack","title":"StackEntry","content":"pub type StackEntry {\n  ValueEntry(runtime.Value)\n  LabelEntry(Label)\n  ActivationEntry(ActivationFrame)\n}\n https://webassembly.github.io/spec/core/exec/runtime.html#stack\nValueEntry(runtime.Value)\n\n\nLabelEntry(Label)\n\n\nActivationEntry(ActivationFrame)\n\n\nSynonyms:\ngwr/execution/stack.StackEntry\ngwr/execution/stack StackEntry","url":"gwr/execution/stack.html#StackEntry"},{"doc":"gwr/execution/stack","title":"create","content":"pub fn create() -&gt; Stack\n\nSynonyms:\ngwr/execution/stack.create\ngwr/execution/stack create","url":"gwr/execution/stack.html#create"},{"doc":"gwr/execution/stack","title":"length","content":"pub fn length(from stack: Stack) -&gt; Int\n\nSynonyms:\ngwr/execution/stack.length\ngwr/execution/stack length","url":"gwr/execution/stack.html#length"},{"doc":"gwr/execution/stack","title":"peek","content":"pub fn peek(from stack: Stack) -&gt; Option(StackEntry)\n\nSynonyms:\ngwr/execution/stack.peek\ngwr/execution/stack peek","url":"gwr/execution/stack.html#peek"},{"doc":"gwr/execution/stack","title":"pop","content":"pub fn pop(from stack: Stack) -&gt; #(Stack, Option(StackEntry))\n\nSynonyms:\ngwr/execution/stack.pop\ngwr/execution/stack pop","url":"gwr/execution/stack.html#pop"},{"doc":"gwr/execution/stack","title":"pop_repeat","content":"pub fn pop_repeat(\n  from stack: Stack,\n  up_to count: Int,\n) -&gt; #(Stack, List(Option(StackEntry)))\n\nSynonyms:\ngwr/execution/stack.pop_repeat\ngwr/execution/stack pop_repeat","url":"gwr/execution/stack.html#pop_repeat"},{"doc":"gwr/execution/stack","title":"push","content":"pub fn push(to stack: Stack, push new_entry: StackEntry) -&gt; Stack\n\nSynonyms:\ngwr/execution/stack.push\ngwr/execution/stack push","url":"gwr/execution/stack.html#push"},{"doc":"gwr/execution/stack","title":"gwr/execution/stack","content":"","url":"gwr/execution/stack.html"},{"doc":"gwr/execution/machine","title":"Configuration","content":"pub type Configuration {\n  Configuration(store: runtime.Store, thread: Thread)\n}\n A configuration consists of the current store and an executing thread.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#configurations\nConfiguration(store: runtime.Store, thread: Thread)\n\n\nSynonyms:\ngwr/execution/machine.Configuration\ngwr/execution/machine Configuration","url":"gwr/execution/machine.html#Configuration"},{"doc":"gwr/execution/machine","title":"Machine","content":"pub type Machine {\n  Machine(\n    module_instance: runtime.ModuleInstance,\n    state: MachineState,\n  )\n}\n\nMachine(\n  module_instance: runtime.ModuleInstance,\n  state: MachineState,\n)\n\n\nSynonyms:\ngwr/execution/machine.Machine\ngwr/execution/machine Machine","url":"gwr/execution/machine.html#Machine"},{"doc":"gwr/execution/machine","title":"MachineState","content":"pub type MachineState {\n  MachineState(configuration: Configuration, stack: stack.Stack)\n}\n\nMachineState(configuration: Configuration, stack: stack.Stack)\n\n\nSynonyms:\ngwr/execution/machine.MachineState\ngwr/execution/machine MachineState","url":"gwr/execution/machine.html#MachineState"},{"doc":"gwr/execution/machine","title":"Thread","content":"pub type Thread {\n  Thread(\n    framestate: stack.FrameState,\n    instructions: List(instruction.Instruction),\n  )\n}\n A thread is a computation over instructions that operates relative to the state of\n a current frame referring to the module instance in which the computation runs, i.e.,\n where the current function originates from.\n \n NOTE: The current version of WebAssembly is single-threaded, but configurations with\n multiple threads may be supported in the future.\n \n https://webassembly.github.io/spec/core/exec/runtime.html#configurations\nThread(\n  framestate: stack.FrameState,\n  instructions: List(instruction.Instruction),\n)\n\n\nSynonyms:\ngwr/execution/machine.Thread\ngwr/execution/machine Thread","url":"gwr/execution/machine.html#Thread"},{"doc":"gwr/execution/machine","title":"address_to_int","content":"pub fn address_to_int(address: Address) -&gt; Int\n\nSynonyms:\ngwr/execution/machine.address_to_int\ngwr/execution/machine address_to_int","url":"gwr/execution/machine.html#address_to_int"},{"doc":"gwr/execution/machine","title":"address_to_string","content":"pub fn address_to_string(address: Address) -&gt; String\n\nSynonyms:\ngwr/execution/machine.address_to_string\ngwr/execution/machine address_to_string","url":"gwr/execution/machine.html#address_to_string"},{"doc":"gwr/execution/machine","title":"allocate_web_assembly_function","content":"pub fn allocate_web_assembly_function(\n  function: Function,\n  store: Store,\n  addresses: List(Address),\n  types_list: List(FunctionType),\n) -&gt; Result(#(Store, List(Address)), String)\n\nSynonyms:\ngwr/execution/machine.allocate_web_assembly_function\ngwr/execution/machine allocate_web_assembly_function","url":"gwr/execution/machine.html#allocate_web_assembly_function"},{"doc":"gwr/execution/machine","title":"call","content":"pub fn call(\n  state: MachineState,\n  index: Int,\n  arguments: List(Value),\n) -&gt; Result(#(MachineState, List(Value)), String)\n\nSynonyms:\ngwr/execution/machine.call\ngwr/execution/machine call","url":"gwr/execution/machine.html#call"},{"doc":"gwr/execution/machine","title":"execute","content":"pub fn execute(\n  current_state: MachineState,\n) -&gt; Result(MachineState, String)\n\nSynonyms:\ngwr/execution/machine.execute\ngwr/execution/machine execute","url":"gwr/execution/machine.html#execute"},{"doc":"gwr/execution/machine","title":"i32_add","content":"pub fn i32_add(\n  state: MachineState,\n) -&gt; Result(MachineState, String)\n\nSynonyms:\ngwr/execution/machine.i32_add\ngwr/execution/machine i32_add","url":"gwr/execution/machine.html#i32_add"},{"doc":"gwr/execution/machine","title":"i32_const","content":"pub fn i32_const(\n  state: MachineState,\n  value: Int,\n) -&gt; Result(MachineState, a)\n\nSynonyms:\ngwr/execution/machine.i32_const\ngwr/execution/machine i32_const","url":"gwr/execution/machine.html#i32_const"},{"doc":"gwr/execution/machine","title":"initialize","content":"pub fn initialize(from module: Module) -&gt; Result(Machine, String)\n\nSynonyms:\ngwr/execution/machine.initialize\ngwr/execution/machine initialize","url":"gwr/execution/machine.html#initialize"},{"doc":"gwr/execution/machine","title":"local_get","content":"pub fn local_get(\n  state: MachineState,\n  index: Int,\n) -&gt; Result(MachineState, String)\n\nSynonyms:\ngwr/execution/machine.local_get\ngwr/execution/machine local_get","url":"gwr/execution/machine.html#local_get"},{"doc":"gwr/execution/machine","title":"gwr/execution/machine","content":"","url":"gwr/execution/machine.html"},{"doc":"gwr/parser/binary_reader","title":"BinaryReader","content":"pub type BinaryReader {\n  BinaryReader(data: BitArray, current_position: Int)\n}\n\nBinaryReader(data: BitArray, current_position: Int)\n\n\nSynonyms:\ngwr/parser/binary_reader.BinaryReader\ngwr/parser/binary_reader BinaryReader","url":"gwr/parser/binary_reader.html#BinaryReader"},{"doc":"gwr/parser/binary_reader","title":"advance","content":"pub fn advance(\n  from reader: BinaryReader,\n  up_to count: Int,\n) -&gt; BinaryReader\n\nSynonyms:\ngwr/parser/binary_reader.advance\ngwr/parser/binary_reader advance","url":"gwr/parser/binary_reader.html#advance"},{"doc":"gwr/parser/binary_reader","title":"bytes_read","content":"pub fn bytes_read(from reader: BinaryReader) -&gt; Int\n\nSynonyms:\ngwr/parser/binary_reader.bytes_read\ngwr/parser/binary_reader bytes_read","url":"gwr/parser/binary_reader.html#bytes_read"},{"doc":"gwr/parser/binary_reader","title":"can_read","content":"pub fn can_read(reader: BinaryReader) -&gt; Bool\n\nSynonyms:\ngwr/parser/binary_reader.can_read\ngwr/parser/binary_reader can_read","url":"gwr/parser/binary_reader.html#can_read"},{"doc":"gwr/parser/binary_reader","title":"create","content":"pub fn create(from data: BitArray) -&gt; BinaryReader\n\nSynonyms:\ngwr/parser/binary_reader.create\ngwr/parser/binary_reader create","url":"gwr/parser/binary_reader.html#create"},{"doc":"gwr/parser/binary_reader","title":"get_remaining","content":"pub fn get_remaining(\n  from reader: BinaryReader,\n) -&gt; Result(BitArray, String)\n\nSynonyms:\ngwr/parser/binary_reader.get_remaining\ngwr/parser/binary_reader get_remaining","url":"gwr/parser/binary_reader.html#get_remaining"},{"doc":"gwr/parser/binary_reader","title":"is_empty","content":"pub fn is_empty(reader: BinaryReader) -&gt; Bool\n\nSynonyms:\ngwr/parser/binary_reader.is_empty\ngwr/parser/binary_reader is_empty","url":"gwr/parser/binary_reader.html#is_empty"},{"doc":"gwr/parser/binary_reader","title":"read","content":"pub fn read(\n  from reader: BinaryReader,\n  take count: Int,\n) -&gt; Result(#(BinaryReader, BitArray), String)\n\nSynonyms:\ngwr/parser/binary_reader.read\ngwr/parser/binary_reader read","url":"gwr/parser/binary_reader.html#read"},{"doc":"gwr/parser/binary_reader","title":"read_remaining","content":"pub fn read_remaining(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, BitArray), String)\n\nSynonyms:\ngwr/parser/binary_reader.read_remaining\ngwr/parser/binary_reader read_remaining","url":"gwr/parser/binary_reader.html#read_remaining"},{"doc":"gwr/parser/binary_reader","title":"gwr/parser/binary_reader","content":"","url":"gwr/parser/binary_reader.html"},{"doc":"gwr/parser/value_parser","title":"parse_name","content":"pub fn parse_name(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, String), String)\n\nSynonyms:\ngwr/parser/value_parser.parse_name\ngwr/parser/value_parser parse_name","url":"gwr/parser/value_parser.html#parse_name"},{"doc":"gwr/parser/value_parser","title":"parse_signed_leb128_integer","content":"pub fn parse_signed_leb128_integer(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Int), String)\n\nSynonyms:\ngwr/parser/value_parser.parse_signed_leb128_integer\ngwr/parser/value_parser parse_signed_leb128_integer","url":"gwr/parser/value_parser.html#parse_signed_leb128_integer"},{"doc":"gwr/parser/value_parser","title":"parse_uninterpreted_leb128_integer","content":"pub fn parse_uninterpreted_leb128_integer(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Int), String)\n\nSynonyms:\ngwr/parser/value_parser.parse_uninterpreted_leb128_integer\ngwr/parser/value_parser parse_uninterpreted_leb128_integer","url":"gwr/parser/value_parser.html#parse_uninterpreted_leb128_integer"},{"doc":"gwr/parser/value_parser","title":"parse_unsigned_leb128_integer","content":"pub fn parse_unsigned_leb128_integer(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Int), String)\n\nSynonyms:\ngwr/parser/value_parser.parse_unsigned_leb128_integer\ngwr/parser/value_parser parse_unsigned_leb128_integer","url":"gwr/parser/value_parser.html#parse_unsigned_leb128_integer"},{"doc":"gwr/parser/value_parser","title":"gwr/parser/value_parser","content":"","url":"gwr/parser/value_parser.html"},{"doc":"gwr/parser/convention_parser","title":"parse_vector","content":"pub fn parse_vector(\n  from reader: BinaryReader,\n  with parse_element: fn(BinaryReader) -&gt;\n    Result(#(BinaryReader, a), String),\n) -&gt; Result(#(BinaryReader, List(a)), String)\n\nSynonyms:\ngwr/parser/convention_parser.parse_vector\ngwr/parser/convention_parser parse_vector","url":"gwr/parser/convention_parser.html#parse_vector"},{"doc":"gwr/parser/convention_parser","title":"gwr/parser/convention_parser","content":"","url":"gwr/parser/convention_parser.html"},{"doc":"gwr/parser/instruction_parser","title":"parse_expression","content":"pub fn parse_expression(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, List(Instruction)), String)\n\nSynonyms:\ngwr/parser/instruction_parser.parse_expression\ngwr/parser/instruction_parser parse_expression","url":"gwr/parser/instruction_parser.html#parse_expression"},{"doc":"gwr/parser/instruction_parser","title":"parse_instruction","content":"pub fn parse_instruction(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Instruction), String)\n\nSynonyms:\ngwr/parser/instruction_parser.parse_instruction\ngwr/parser/instruction_parser parse_instruction","url":"gwr/parser/instruction_parser.html#parse_instruction"},{"doc":"gwr/parser/instruction_parser","title":"gwr/parser/instruction_parser","content":"","url":"gwr/parser/instruction_parser.html"},{"doc":"gwr/parser/types_parser","title":"parse_function_type","content":"pub fn parse_function_type(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, FunctionType), String)\n Decodes a bit array into a FunctionType. The FunctionType bit array begins with 0x60 byte id\n and follows with 2 vectors, each containing an arbitrary amount of 1-byte ValueType(s).\n The first vector represents the list of parameter types of the function, while the second vector represents\n the list of result types returned by the function.\nSynonyms:\ngwr/parser/types_parser.parse_function_type\ngwr/parser/types_parser parse_function_type","url":"gwr/parser/types_parser.html#parse_function_type"},{"doc":"gwr/parser/types_parser","title":"parse_global_type","content":"pub fn parse_global_type(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, GlobalType), String)\n\nSynonyms:\ngwr/parser/types_parser.parse_global_type\ngwr/parser/types_parser parse_global_type","url":"gwr/parser/types_parser.html#parse_global_type"},{"doc":"gwr/parser/types_parser","title":"parse_limits","content":"pub fn parse_limits(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Limits), String)\n\nSynonyms:\ngwr/parser/types_parser.parse_limits\ngwr/parser/types_parser parse_limits","url":"gwr/parser/types_parser.html#parse_limits"},{"doc":"gwr/parser/types_parser","title":"parse_value_type","content":"pub fn parse_value_type(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, ValueType), String)\n\nSynonyms:\ngwr/parser/types_parser.parse_value_type\ngwr/parser/types_parser parse_value_type","url":"gwr/parser/types_parser.html#parse_value_type"},{"doc":"gwr/parser/types_parser","title":"gwr/parser/types_parser","content":"","url":"gwr/parser/types_parser.html"},{"doc":"gwr/parser/module_parser","title":"function_index_id","content":"pub const function_index_id: Int\n\nSynonyms:\ngwr/parser/module_parser.function_index_id\ngwr/parser/module_parser function_index_id","url":"gwr/parser/module_parser.html#function_index_id"},{"doc":"gwr/parser/module_parser","title":"global_index_id","content":"pub const global_index_id: Int\n\nSynonyms:\ngwr/parser/module_parser.global_index_id\ngwr/parser/module_parser global_index_id","url":"gwr/parser/module_parser.html#global_index_id"},{"doc":"gwr/parser/module_parser","title":"memory_index_id","content":"pub const memory_index_id: Int\n\nSynonyms:\ngwr/parser/module_parser.memory_index_id\ngwr/parser/module_parser memory_index_id","url":"gwr/parser/module_parser.html#memory_index_id"},{"doc":"gwr/parser/module_parser","title":"table_index_id","content":"pub const table_index_id: Int\n\nSynonyms:\ngwr/parser/module_parser.table_index_id\ngwr/parser/module_parser table_index_id","url":"gwr/parser/module_parser.html#table_index_id"},{"doc":"gwr/parser/module_parser","title":"parse_export","content":"pub fn parse_export(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Export), String)\n\nSynonyms:\ngwr/parser/module_parser.parse_export\ngwr/parser/module_parser parse_export","url":"gwr/parser/module_parser.html#parse_export"},{"doc":"gwr/parser/module_parser","title":"parse_global","content":"pub fn parse_global(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Global), String)\n\nSynonyms:\ngwr/parser/module_parser.parse_global\ngwr/parser/module_parser parse_global","url":"gwr/parser/module_parser.html#parse_global"},{"doc":"gwr/parser/module_parser","title":"parse_memory","content":"pub fn parse_memory(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Memory), String)\n\nSynonyms:\ngwr/parser/module_parser.parse_memory\ngwr/parser/module_parser parse_memory","url":"gwr/parser/module_parser.html#parse_memory"},{"doc":"gwr/parser/module_parser","title":"gwr/parser/module_parser","content":"","url":"gwr/parser/module_parser.html"},{"doc":"gwr/parser/binary_parser","title":"parse_binary_module","content":"pub fn parse_binary_module(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Binary), String)\n\nSynonyms:\ngwr/parser/binary_parser.parse_binary_module\ngwr/parser/binary_parser parse_binary_module","url":"gwr/parser/binary_parser.html#parse_binary_module"},{"doc":"gwr/parser/binary_parser","title":"parse_code","content":"pub fn parse_code(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Code), String)\n\nSynonyms:\ngwr/parser/binary_parser.parse_code\ngwr/parser/binary_parser parse_code","url":"gwr/parser/binary_parser.html#parse_code"},{"doc":"gwr/parser/binary_parser","title":"parse_function_code","content":"pub fn parse_function_code(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, FunctionCode), String)\n\nSynonyms:\ngwr/parser/binary_parser.parse_function_code\ngwr/parser/binary_parser parse_function_code","url":"gwr/parser/binary_parser.html#parse_function_code"},{"doc":"gwr/parser/binary_parser","title":"parse_locals_declaration","content":"pub fn parse_locals_declaration(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, LocalsDeclaration), String)\n\nSynonyms:\ngwr/parser/binary_parser.parse_locals_declaration\ngwr/parser/binary_parser parse_locals_declaration","url":"gwr/parser/binary_parser.html#parse_locals_declaration"},{"doc":"gwr/parser/binary_parser","title":"parse_section","content":"pub fn parse_section(\n  from reader: BinaryReader,\n) -&gt; Result(#(BinaryReader, Section), String)\n\nSynonyms:\ngwr/parser/binary_parser.parse_section\ngwr/parser/binary_parser parse_section","url":"gwr/parser/binary_parser.html#parse_section"},{"doc":"gwr/parser/binary_parser","title":"gwr/parser/binary_parser","content":"","url":"gwr/parser/binary_parser.html"},{"doc":"gwr/execution/instance","title":"WebAssemblyInstance","content":"pub type WebAssemblyInstance {\n  WebAssemblyInstance(\n    binary: binary.Binary,\n    machine: machine.Machine,\n  )\n}\n\nWebAssemblyInstance(\n  binary: binary.Binary,\n  machine: machine.Machine,\n)\n\n\nSynonyms:\ngwr/execution/instance.WebAssemblyInstance\ngwr/execution/instance WebAssemblyInstance","url":"gwr/execution/instance.html#WebAssemblyInstance"},{"doc":"gwr/execution/instance","title":"call","content":"pub fn call(\n  instance: WebAssemblyInstance,\n  name: String,\n  arguments: List(Value),\n) -&gt; Result(#(WebAssemblyInstance, List(Value)), String)\n\nSynonyms:\ngwr/execution/instance.call\ngwr/execution/instance call","url":"gwr/execution/instance.html#call"},{"doc":"gwr/execution/instance","title":"create","content":"pub fn create(\n  from data: BitArray,\n) -&gt; Result(WebAssemblyInstance, String)\n\nSynonyms:\ngwr/execution/instance.create\ngwr/execution/instance create","url":"gwr/execution/instance.html#create"},{"doc":"gwr/execution/instance","title":"gwr/execution/instance","content":"","url":"gwr/execution/instance.html"},{"doc":"gwr/execution/logic","title":"gwr/execution/logic","content":"","url":"gwr/execution/logic.html"}]);